@@ -15,7 +15,8 @@ import socket
 import struct
 import traceback
 import copy
-from urllib.parse import quote_plus, urlparse
+import threading
+from urllib.parse import quote_plus, urlparse, unquote
 from datetime import datetime, timezone
 from typing import (
     Union,
@@ -58,6 +59,11 @@ from mockintosh.params import (
 from mockintosh.logs import Logs, LogRecord
 from mockintosh.stats import Stats
 from mockintosh.templating import TemplateRenderer, RenderingQueue
+from mockintosh.exceptions import (
+    AsyncProducerListHasNoPayloadsMatchingTags,
+    AsyncProducerPayloadLoopEnd,
+    AsyncProducerDatasetLoopEnd
+)
 
 OPTIONS = 'options'
 ORIGIN = 'Origin'
@@ -277,7 +283,7 @@ class GenericHandler(tornado.web.RequestHandler, BaseHandler):
         definition_engine: str,
         rendering_queue: RenderingQueue,
         interceptors: list,
-        unhandled_data,
+        unhandled_data: None,
         fallback_to: Union[str, None],
         tags: list
     ) -> None:
@@ -355,6 +361,9 @@ class GenericHandler(tornado.web.RequestHandler, BaseHandler):
             self.determine_headers()
             self.log_request()
 
+            if response.trigger_async_producer is not None:
+                self.trigger_async_producer(response.trigger_async_producer)
+
             self.rendered_body = self.render_template()
 
             if self.rendered_body is None:
@@ -797,7 +806,15 @@ class GenericHandler(tornado.web.RequestHandler, BaseHandler):
             context = alternative.context
             internal_endpoint_id = alternative.internal_endpoint_id
             performance_profile = alternative.performance_profile
-            return (_id, response, params, context, dataset, internal_endpoint_id, performance_profile)
+            return (
+                _id,
+                response,
+                params,
+                context,
+                dataset,
+                internal_endpoint_id,
+                performance_profile
+            )
 
         self.write(reason)
         await self.raise_http_error(400)
@@ -1183,7 +1200,7 @@ class GenericHandler(tornado.web.RequestHandler, BaseHandler):
 
         http_verb = getattr(client, self.request.method.lower())
         try:
-            if self.request.method.upper() in ('POST', 'PUT', 'PATCH', 'DELETE'):
+            if self.request.method.upper() in ('POST', 'PUT', 'PATCH'):
                 resp = await http_verb(url, headers=headers, timeout=FALLBACK_TO_TIMEOUT, data=data, files=files)
             else:
                 resp = await http_verb(url, headers=headers, timeout=FALLBACK_TO_TIMEOUT)
@@ -1233,6 +1250,68 @@ class GenericHandler(tornado.web.RequestHandler, BaseHandler):
         client_mime_types = [parsed.mime_type for parsed in parsed_header if parsed.mime_type != '*/*']
         return (client_mime_types and set(client_mime_types).issubset(IMAGE_MIME_TYPES)) or ext in IMAGE_EXTENSIONS
 
+    def trigger_async_producer(self, value: Union[int, str]):
+        from mockintosh.services.asynchronous import (
+            AsyncService,
+            AsyncProducer
+        )
+
+        if isinstance(value, int):
+            try:
+                producer = AsyncProducer.producers[value]
+                try:
+                    producer.check_tags()
+                    producer.check_payload_lock()
+                    producer.check_dataset_lock()
+                    t = threading.Thread(target=producer.produce, args=(), kwargs={
+                        'ignore_delay': True
+                    })
+                    t.daemon = True
+                    t.start()
+                except (
+                    AsyncProducerListHasNoPayloadsMatchingTags,
+                    AsyncProducerPayloadLoopEnd,
+                    AsyncProducerDatasetLoopEnd
+                ) as e:
+                    self.set_status(410)
+                    self.write(str(e))
+                    raise NewHTTPError()
+            except IndexError:
+                self.set_status(400)
+                self.write('Invalid producer index!')
+                raise NewHTTPError()
+        else:
+            producer = None
+            actor_name = unquote(value)
+            for service in AsyncService.services:
+                for actor in service.actors:
+                    if actor.name == actor_name:
+                        if actor.producer is None:  # pragma: no cover
+                            continue
+                        producer = actor.producer
+                        try:
+                            producer.check_tags()
+                            producer.check_payload_lock()
+                            producer.check_dataset_lock()
+                            t = threading.Thread(target=actor.producer.produce, args=(), kwargs={
+                                'ignore_delay': True
+                            })
+                            t.daemon = True
+                            t.start()
+                        except (
+                            AsyncProducerListHasNoPayloadsMatchingTags,
+                            AsyncProducerPayloadLoopEnd,
+                            AsyncProducerDatasetLoopEnd
+                        ) as e:
+                            self.set_status(410)
+                            self.write(str(e))
+                            raise NewHTTPError()
+
+            if producer is None:
+                self.set_status(400)
+                self.write('No producer actor is found for: %r' % actor_name)
+                raise NewHTTPError()
+
 
 class AsyncHandler(BaseHandler):
     """Class to handle mocked async data."""
@@ -1254,6 +1333,7 @@ class AsyncHandler(BaseHandler):
         value: Union[str, None] = None,
         key: Union[str, None] = None,
         headers: Union[dict, None] = None,
+        amqp_properties: Union[dict, None] = None,
         context: Union[dict, None] = None,
         params: Union[dict, None] = None
     ):
@@ -1283,6 +1363,7 @@ class AsyncHandler(BaseHandler):
         self.value = value
         self.key = key
         self.headers = headers
+        self.amqp_properties = amqp_properties
         self.response_body = None
         self.response_headers = None
 
@@ -1336,14 +1417,15 @@ class AsyncHandler(BaseHandler):
 
         return rendered
 
-    def render_attributes(self):
-        self.key, self.value, self.headers = self._render_attributes(
+    def render_attributes(self) -> tuple:
+        self.key, self.value, self.headers, self.amqp_properties = self._render_attributes(
             self.key,
             self.value,
-            self.headers
+            self.headers,
+            self.amqp_properties
         )
         self.replica_request = self.build_replica_request()
-        return self.key, self.value, self.headers
+        return self.key, self.value, self.headers, self.amqp_properties
 
     def add_params(self, context):
         return context
@@ -1415,6 +1497,8 @@ class AsyncHandler(BaseHandler):
                 value = value.path
             request.headers[key.title()] = value
 
+        request.headers.update(self.amqp_properties)
+
         # Query String
         if self.key is not None:
             request.queryString['key'] = self.key
@@ -1454,6 +1538,7 @@ class AsyncHandler(BaseHandler):
             return response
 
         response.headers = self.response_headers
+        response.headers.update(self.amqp_properties)
         response.body = self.response_body
 
         return response
