@@ -561,6 +561,26 @@ class IntegrationTests(unittest.TestCase):
         self.assertEqual(0, srv_stats['request_counter'])
 
     def test_unhandled(self):
+        # testing disabled
+        resp = httpx.post(MGMT + '/unhandled', json=False, verify=False)
+        resp.raise_for_status()
+
+        resp = httpx.delete(MGMT + '/unhandled', verify=False)
+        resp.raise_for_status()
+
+        path = '/unhandled-%s' % time.time()
+        resp = httpx.get(SRV1 + path)
+        self.assertEqual(404, resp.status_code)
+
+        resp = httpx.get(MGMT + '/unhandled?format=yaml', verify=False)
+        resp.raise_for_status()
+        self.assertEqual(resp.headers['x-mockintosh-unhandled-data'], 'false')
+        self.assertEqual(resp.text, 'services: []\n')
+
+        # testing enabled
+        resp = httpx.post(SRV1 + '/__admin/unhandled', json=True)
+        resp.raise_for_status()
+
         path = '/unhandled-%s' % time.time()
         resp = httpx.get(SRV1 + path, headers={"hdr1": "val1", "hdr2": "val2", "hdr3": "val3"})
         self.assertEqual(404, resp.status_code)
@@ -568,6 +588,8 @@ class IntegrationTests(unittest.TestCase):
         resp = httpx.get(MGMT + '/unhandled?format=yaml', verify=False)
         resp.raise_for_status()
         self.assertTrue(resp.text.startswith('services:'))
+        self.assertNotEqual(resp.text, 'services: []\n')
+        self.assertEqual(resp.headers['x-mockintosh-unhandled-data'], 'true')
 
         resp = httpx.get(MGMT + '/unhandled', verify=False)
         resp.raise_for_status()
@@ -834,6 +856,9 @@ class IntegrationTests(unittest.TestCase):
         resp = httpx.delete(SRV7 + '/sub/__admin/unhandled')
         resp.raise_for_status()
 
+        resp = httpx.post(SRV7 + '/sub/__admin/unhandled', json=True)
+        resp.raise_for_status()
+
         resp = httpx.get(SRV7 + '/')
         self.assertEqual(200, resp.status_code)
         self.assertEqual("no fallback", resp.text)
@@ -867,6 +892,9 @@ class IntegrationTests(unittest.TestCase):
         endps[1]['response'].pop('headers')
         self.assertEqual(exp, rdata)
 
+        resp = httpx.post(SRV7 + '/sub/__admin/unhandled', json=False)
+        resp.raise_for_status()
+
     def test_qstr_multiparam(self):
         resp = httpx.get(SRV1 + '/qstr-multiparam1?param[]=v1&param[]=v2')
         resp.raise_for_status()
@@ -1028,6 +1056,29 @@ class IntegrationTests(unittest.TestCase):
         else:
             self.fail("Did not capture the message")
 
+    def test_http_trigger_async(self):
+        topic = "on-demand1"
+        produce(topic, None, None)
+        kafka_consume_expected(topic)
+
+        # triggering first queue
+        resp = httpx.get(SRV1 + '/trigger-async')
+        resp.raise_for_status()
+        time.sleep(5)
+        msgs = kafka_consume_expected(topic)
+        self.assertTrue(msgs)
+
+        queue = "produce-reaction1"
+        produce(topic, None, None)
+        kafka_consume_expected(topic)
+
+        # triggering second queue
+        resp = httpx.get(SRV1 + '/trigger-async')
+        resp.raise_for_status()
+        time.sleep(5)
+        msgs = kafka_consume_expected(queue)
+        self.assertTrue(msgs)
+
 
 def kafka_consume_expected(topic, group='0', timeout=1.0, mfilter=lambda x: True, validator=lambda x: None,
                            after_subscribe=lambda: None):
